from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Boolean, String, Int

Pypgatk_Cli_Generate_Decoy_V0_1_0 = CommandToolBuilder(tool="pypgatk_cli_generate_decoy", base_command=["pypgatk_cli", "generate-decoy"], inputs=[ToolInput(tag="in_config_file", input_type=File(optional=True), prefix="--config_file", doc=InputDocumentation(doc="Configuration file for the protein database\ndecoy generation")), ToolInput(tag="in_output_database", input_type=File(optional=True), prefix="--output_database", doc=InputDocumentation(doc="Output file for decoy database")), ToolInput(tag="in_input_database", input_type=File(optional=True), prefix="--input_database", doc=InputDocumentation(doc="FASTA file of target proteins sequences for\nwhich to create decoys (*.fasta|*.fa)")), ToolInput(tag="in_method", input_type=Boolean(optional=True), prefix="--method", doc=InputDocumentation(doc="[protein-reverse|protein-shuffle|decoypyrat|pgdbdeep]\nThe method that would be used to generate\nthe decoys: protein-reverse: reverse protein\nsequences protein-shuffle: shuffle protein\nsequences decoypyrat: method developed for\nproteogenomics that shuffle redundant\npeptides in decoy databases pgdbdeep: method\ndeveloped for proteogenomics developed by\npypgatk")), ToolInput(tag="in_decoy_prefix", input_type=String(optional=True), prefix="--decoy_prefix", doc=InputDocumentation(doc="Set accession prefix for decoy proteins in\noutput. Default=DECOY_")), ToolInput(tag="in_enzyme", input_type=Boolean(optional=True), prefix="--enzyme", doc=InputDocumentation(doc="[Trypsin|Arg-C|Arg-C/P|Asp-N|Asp-N/B|Asp-N_ambic|Chymotrypsin|Chymotrypsin/P|CNBr|Formic_acid|Lys-C|Lys-N|Lys-C/P|PepsinA|TrypChymo|Trypsin/P|V8-DE|V8-E|leukocyte elastase|proline endopeptidase|glutamyl endopeptidase|alphaLP|2-iodobenzoate|iodosobenzoate|staphylococcal protease/D|proline-endopeptidase/HKR|Glu-C+P|PepsinA + P|cyanogen-bromide|Clostripain/P|elastase-trypsin-chymotrypsin|unspecific cleavage]\nEnzyme used for clevage the protein sequence\n(Default: Trypsin)")), ToolInput(tag="in_cleavage_position", input_type=Boolean(optional=True), prefix="--cleavage_position", doc=InputDocumentation(doc="[c|n]       Set cleavage to be c or n terminal of\nspecified cleavage sites. Options [c, n],\nDefault = c")), ToolInput(tag="in_max_missed_cleavages", input_type=Int(optional=True), prefix="--max_missed_cleavages", doc=InputDocumentation(doc="Number of allowed missed cleavages in the\nprotein sequence when digestion is performed")), ToolInput(tag="in_min_peptide_length", input_type=Int(optional=True), prefix="--min_peptide_length", doc=InputDocumentation(doc="Set minimum length of peptides (Default = 5)")), ToolInput(tag="in_max_peptide_length", input_type=Int(optional=True), prefix="--max_peptide_length", doc=InputDocumentation(doc="Set maximum length of peptides (Default =\n100)")), ToolInput(tag="in_max_iterations", input_type=Int(optional=True), prefix="--max_iterations", doc=InputDocumentation(doc="Set maximum number of times to shuffle a\npeptide to make it non-target before\nfailing. Default=100")), ToolInput(tag="in_do_not_shuffle", input_type=Boolean(optional=True), prefix="--do_not_shuffle", doc=InputDocumentation(doc="Turn OFF shuffling of decoy peptides that\nare in the target database. Default=false")), ToolInput(tag="in_do_not_switch", input_type=Boolean(optional=True), prefix="--do_not_switch", doc=InputDocumentation(doc="Turn OFF switching of cleavage site with\npreceding amino acid. Default=false")), ToolInput(tag="in_temp_file", input_type=File(optional=True), prefix="--temp_file", doc=InputDocumentation(doc="Set temporary file to write decoys prior to\nshuffling. Default=tmp.fa")), ToolInput(tag="in_no_isobaric", input_type=Boolean(optional=True), prefix="--no_isobaric", doc=InputDocumentation(doc="Do not make decoy peptides isobaric.\nDefault=false")), ToolInput(tag="in_keep_target_hits", input_type=Boolean(optional=True), prefix="--keep_target_hits", doc=InputDocumentation(doc="Keep peptides duplicate in target and decoy")), ToolInput(tag="in_databases", input_type=String(), position=0, doc=InputDocumentation(doc="--memory_save                   Slower but uses less memory (does not store"))], outputs=[ToolOutput(tag="out_output_database", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_database", type_hint=File()), doc=OutputDocumentation(doc="Output file for decoy database"))], container="quay.io/biocontainers/pypgatk:0.0.16--py_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Pypgatk_Cli_Generate_Decoy_V0_1_0().translate("wdl")

